@@ -57,6 +57,8 @@ from kafka.errors import CorruptRecordException, UnsupportedCodecError
 
 class LegacyRecordBase(object):
 
+    __slots__ = ()
+
     HEADER_STRUCT_V0 = struct.Struct(
         ">q"  # BaseOffset => Int64
         "i"  # Length => Int32
@@ -127,6 +129,9 @@ class LegacyRecordBase(object):
 
 class LegacyRecordBatch(ABCRecordBatch, LegacyRecordBase):
 
+    __slots__ = ("_buffer", "_magic", "_offset", "_crc", "_timestamp",
+                 "_attributes", "_decompressed")
+
     def __init__(self, buffer, magic):
         self._buffer = memoryview(buffer)
         self._magic = magic
@@ -254,7 +259,7 @@ class LegacyRecordBatch(ABCRecordBatch, LegacyRecordBase):
                 # There should only ever be a single layer of compression
                 assert not attrs & self.CODEC_MASK, (
                     'MessageSet at offset %d appears double-compressed. This '
-                    'should not happen -- check your producers!' % offset)
+                    'should not happen -- check your producers!' % (offset,))
 
                 # When magic value is greater than 0, the timestamp
                 # of a compressed message depends on the
@@ -336,6 +341,8 @@ class LegacyRecord(ABCRecord):
 
 class LegacyRecordBatchBuilder(ABCRecordBatchBuilder, LegacyRecordBase):
 
+    __slots__ = ("_magic", "_compression_type", "_batch_size", "_buffer")
+
     def __init__(self, magic, compression_type, batch_size):
         self._magic = magic
         self._compression_type = compression_type
